Documentation
¶
Overview ¶
Package instrumentation provides types to represent the code libraries that provide OpenTelemetry instrumentation. These types are used in the OpenTelemetry signal pipelines to identify the source of telemetry.
See https://github.com/open-telemetry/oteps/blob/d226b677d73a785523fe9b9701be13225ebc528d/text/0083-component.md and https://github.com/open-telemetry/oteps/blob/d226b677d73a785523fe9b9701be13225ebc528d/text/0201-scope-attributes.md for more information.
Index ¶
- type Librarydeprecated
- type Scope
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Scope ¶ added in v1.8.0
type Scope struct {
// Name is the name of the instrumentation scope. This should be the
// Go package name of that scope.
Name string
// Version is the version of the instrumentation scope.
Version string
// SchemaURL of the telemetry emitted by the scope.
SchemaURL string
// Attributes of the telemetry emitted by the scope.
Attributes attribute.Set
}
Scope represents the instrumentation scope.
Click to show internal directories.
Click to hide internal directories.