package internal

import "go.opentelemetry.io/otel/sdk/metric/internal"

Package internal provides internal functionality for the metric package.

Index

Functions

func ReuseSlice

func ReuseSlice[T any](slice []T, n int) []T

ReuseSlice returns a zeroed view of slice if its capacity is greater than or equal to n. Otherwise, it returns a new []T with capacity equal to n.

Source Files

reuse_slice.go

Directories

PathSynopsis
internal/aggregatePackage aggregate provides aggregate types used compute aggregations and cycle the state of metric measurements made by the SDK.
internal/observPackage observ provides experimental observability instrumentation for the metric reader.
internal/reservoirPackage reservoir contains experimental features used by built-in exemplar reservoirs which require coordination with the metrics SDK.
internal/xPackage x contains support for OTel metric SDK experimental features.
Version
v1.43.0 (latest)
Published
Apr 3, 2026
Platform
linux/amd64
Last checked
1 day ago

Tools for package owners.