Documentation
¶
Overview ¶
Package x documents experimental features for go.opentelemetry.io/otel/sdk/log.
Package x documents experimental features for go.opentelemetry.io/otel/sdk/log.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Observability = newFeature( []string{"OBSERVABILITY", "SELF_OBSERVABILITY"}, func(v string) (string, bool) { if strings.EqualFold(v, "true") { return v, true } return "", false }, )
Observability is an experimental feature flag that determines whether SDK observability metrics are enabled.
To enable this feature, set the OTEL_GO_X_OBSERVABILITY environment variable to the case-insensitive string value of "true" (i.e., "True" and "TRUE" will also enable this).
Functions ¶
This section is empty.
Types ¶
type Feature ¶ added in v0.14.0
type Feature[T any] struct { // contains filtered or unexported fields }
Feature is an experimental feature control flag. It provides a uniform way to interact with these feature flags and parse their values.
Click to show internal directories.
Click to hide internal directories.