package observ
import "go.opentelemetry.io/otel/sdk/trace/internal/observ"
Package observ provides observability instrumentation for the OTel trace SDK package.
Index ¶
- Constants
- Variables
- func BSPComponentName(id int64) attribute.KeyValue
- func SSPComponentName(id int64) attribute.KeyValue
- type BSP
- func NewBSP(id int64, qLen func() int64, qMax int64) (*BSP, error)
- func (b *BSP) Processed(ctx context.Context, n int64)
- func (b *BSP) ProcessedQueueFull(ctx context.Context, n int64)
- func (b *BSP) Shutdown() error
- type SSP
- type Tracer
Constants ¶
const ( // ScopeName is the name of the instrumentation scope. ScopeName = "go.opentelemetry.io/otel/sdk/trace/internal/observ" // SchemaURL is the schema URL of the instrumentation. SchemaURL = semconv.SchemaURL )
Variables ¶
var ErrQueueFull = otelconv.SDKProcessorSpanProcessed{}.AttrErrorType( otelconv.ErrorTypeAttr("queue_full"), )
ErrQueueFull is the attribute value for the "queue_full" error type.
Functions ¶
func BSPComponentName ¶
BSPComponentName returns the component name attribute for a BatchSpanProcessor with the given ID.
func SSPComponentName ¶
SSPComponentName returns the component name attribute for a SimpleSpanProcessor with the given ID.
Types ¶
type BSP ¶
type BSP struct {
// contains filtered or unexported fields
}
BSP is the instrumentation for an OTel SDK BatchSpanProcessor.
func NewBSP ¶
func (*BSP) Processed ¶
func (*BSP) ProcessedQueueFull ¶
func (*BSP) Shutdown ¶
type SSP ¶
type SSP struct {
// contains filtered or unexported fields
}
SSP is the instrumentation for an OTel SDK SimpleSpanProcessor.
func NewSSP ¶
NewSSP returns instrumentation for an OTel SDK SimpleSpanProcessor with the provided ID.
If the experimental observability is disabled, nil is returned.
func (*SSP) SpanProcessed ¶
SpanProcessed records that a span has been processed by the SimpleSpanProcessor. If err is non-nil, it records the processing error as an attribute.
type Tracer ¶
type Tracer struct {
// contains filtered or unexported fields
}
Tracer is instrumentation for an OTel SDK Tracer.
func NewTracer ¶
func (Tracer) Enabled ¶
func (Tracer) SpanEnded ¶
func (Tracer) SpanLive ¶
func (Tracer) SpanStarted ¶
Source Files ¶
batch_span_processor.go doc.go simple_span_processor.go tracer.go
- Version
- v1.41.0
- Published
- Mar 2, 2026
- Platform
- linux/amd64
- Imports
- 12 packages
- Last checked
- 3 hours ago –
Tools for package owners.